@@ -2,10 +2,10 @@ from workos.resources.base import WorkOSBaseResource
 
 
 class WorkOSOrganization(WorkOSBaseResource):
-    """Representation of a User Profile and Access Token as returned by WorkOS through the SSO feature.
+    """Representation of WorkOS Organization as returned by WorkOS through the Organizations feature.
 
     Attributes:
-        OBJECT_FIELDS (list): List of fields a WorkOSProfileAndToken is comprised of.
+        OBJECT_FIELDS (list): List of fields a WorkOSOrganization is comprised of.
     """
 
     OBJECT_FIELDS = [
