@@ -4,23 +4,24 @@ import workos
 from workos.exceptions import ConfigurationException
 
 AUDIT_LOGS_MODULE = "AuditLogs"
-AUDIT_TRAIL_MODULE = "AuditTrail"
 DIRECTORY_SYNC_MODULE = "DirectorySync"
+EVENTS_MODULE = "Events"
 ORGANIZATIONS_MODULE = "Organizations"
 PASSWORDLESS_MODULE = "Passwordless"
 PORTAL_MODULE = "Portal"
 SSO_MODULE = "SSO"
 WEBHOOKS_MODULE = "Webhooks"
 MFA_MODULE = "MFA"
+USER_MANAGEMENT_MODULE = "UserManagement"
 
 REQUIRED_SETTINGS_FOR_MODULE = {
     AUDIT_LOGS_MODULE: [
         "api_key",
     ],
-    AUDIT_TRAIL_MODULE: [
+    DIRECTORY_SYNC_MODULE: [
         "api_key",
     ],
-    DIRECTORY_SYNC_MODULE: [
+    EVENTS_MODULE: [
         "api_key",
     ],
     ORGANIZATIONS_MODULE: [
@@ -38,6 +39,7 @@ REQUIRED_SETTINGS_FOR_MODULE = {
     ],
     WEBHOOKS_MODULE: ["api_key"],
     MFA_MODULE: ["api_key"],
+    USER_MANAGEMENT_MODULE: ["client_id", "api_key"],
 }
 
 
