@@ -23,7 +23,6 @@ class Webhooks(object):
     DEFAULT_TOLERANCE = 180
 
     def verify_event(self, payload, sig_header, secret, tolerance=DEFAULT_TOLERANCE):
-
         if payload is None:
             raise ValueError("Payload body is missing and is a required parameter")
         if sig_header is None:
@@ -58,7 +57,7 @@ class Webhooks(object):
         )
 
         # Set expected signature value based on env var secret
-        unhashed_string = "{0}.{1}".format(issued_timestamp, event_body)
+        unhashed_string = "{0}.{1}".format(issued_timestamp, event_body.decode("utf-8"))
         expected_signature = hmac.new(
             secret.encode("utf-8"),
             unhashed_string.encode("utf-8"),
